@@ -1,4 +1,3 @@
-from bunq.sdk.context.user_context import UserContext
 from tests.bunq_test import BunqSdkTestCase
 
 
@@ -14,7 +13,11 @@ class TestUserContext(BunqSdkTestCase):
         cls._API_CONTEXT = cls._get_api_context()
 
     def test_build_user_context(self):
-        user_context = UserContext(self._API_CONTEXT.session_context.user_id)
+        from bunq.sdk.context.user_context import UserContext
+        user_context = UserContext(
+            self._API_CONTEXT.session_context.user_id,
+            self._API_CONTEXT.session_context.get_user_reference()
+        )
         user_context.refresh_user_context()
 
         self.assertIsNotNone(user_context.user_id)
